<?xml version="1.0" encoding="UTF-8"?>
<?Kopete Flag:TransformAllMessages?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="html"/>


	<xsl:template match="document">
		<xsl:variable name="messages" select="message"/>
		<xsl:for-each select="message">
			<xsl:call-template name="processMessage">
				<xsl:with-param name="messages" select="$messages"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="processMessage">

		<xsl:param name="messages"/>
		<xsl:variable name="position" select="position()"/>
		<xsl:variable name="prev" select="$messages[position()=$position - 1]"/>
		<xsl:variable name="curr" select="$messages[position()=$position]"/>
		<xsl:variable name="prevId" select="$prev/from/contact/@contactId"/>
		<xsl:variable name="currId" select="$curr/from/contact/@contactId"/>
		<xsl:variable name="image-location"><xsl:value-of select="$appdata"/>Mothra/</xsl:variable>

		<div class="KopeteMessage" style="margin: 0.5ex; margin-top: 1em; margin-bottom: 1em;">
			<xsl:if test="not($prevId=$currId)">
				<!-- Header -->
				<div id="MessageHeader">
					<xsl:attribute name="style">
						padding-left: 1ex;
						padding-right: 1ex;
						color: #000;
						<xsl:choose>
							<xsl:when test="@route='inbound'">
								border-bottom: 0.1em solid afafff;
								background-color: #E3ECF8;
							</xsl:when>
							<xsl:when test="@route='outbound'">
								border-bottom: 0.1em solid #ffafaf;
								background-color: #FFFDEC;
							</xsl:when>
						</xsl:choose>
					</xsl:attribute> 
	
					<!-- Protocol Icon -->
					<div style="float: left;">
						<img style="margin-top: 0.1em; margin-right: 1ex;">
							<xsl:attribute name="src">
								<xsl:value-of select="$curr/from/contact/@protocolIcon"/>
							</xsl:attribute>
						</img>
					</div>
				
					<!-- MetaContacts Display Name && Messages Timestamp -->
					<div>
						<span style="font-weight: bold; text-align: left;">
							<xsl:value-of select="$curr/from/contact/metaContactDisplayName/@text" disable-output-escaping="yes"/>
							<xsl:if test="$curr/from/contact/metaContactDisplayName/@text != $curr/from/contact/contactDisplayName/@text">
								<i> (<xsl:value-of select="$curr/from/contact/contactDisplayName/@text" disable-output-escaping="yes"/>)</i>
							</xsl:if>
						</span>
						<div style="float: right; font-weight: normal;"><xsl:value-of select="$curr/@formattedTimestamp"/></div>
					</div>
				</div>
	
				<!-- Message Body -->
				<div>
					<xsl:attribute name="style">
						padding-left: 1ex;
						padding-right: 1ex;
						padding-top: 0.25em;
						line-height: 1.2;
						<xsl:if	test="@route='internal'">
							border: 0.1em dashed #ccc;
							background-color: #fafafa;
						</xsl:if>
					</xsl:attribute>
							<xsl:if test="@route='internal'">
								<img style="margin-top: 0.1em; margin-right: 1ex;"><xsl:attribute name="src"><xsl:value-of select="$image-location" />internal.png</xsl:attribute></img> 
							</xsl:if>
					<xsl:call-template name="renderFirstMessage"/>
					<xsl:call-template name="renderRest">
						<xsl:with-param name="messages" select="$messages"/>
						<xsl:with-param name="withId" select="$currId"/>
						<xsl:with-param name="position" select="$position + 1"/>
					</xsl:call-template>
				</div>
			</xsl:if>
		</div>
	</xsl:template>

	<xsl:template name="renderRest">
		<xsl:param name="messages"/>
		<xsl:param name="withId"/>
		<xsl:param name="position"/>
		<xsl:variable name="curr" select="$messages[position()=$position]"/>
		<xsl:variable name="currId" select="$curr/from/contact/@contactId"/>
		<xsl:if test="$withId = $currId">
			<!-- call-template doesn't support select=. fake it. -->
			<xsl:for-each select="$curr">
				<xsl:call-template name="renderLaterMessage"/>
			</xsl:for-each>
			<xsl:call-template name="renderRest">
				<xsl:with-param name="messages" select="$messages"/>
				<xsl:with-param name="withId" select="$currId"/>
				<xsl:with-param name="position" select="$position + 1"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<xsl:template name="renderFirstMessage">
		<xsl:call-template name="renderMessageBody"/>
	</xsl:template>

	<xsl:template name="renderLaterMessage">
		<hr>
			<xsl:attribute name="style">
				border: 0.1em dashed #eee;
				margin: 0;
			</xsl:attribute>
		</hr>
		<xsl:call-template name="renderMessageBody"/>
	</xsl:template>

	<xsl:template name="renderMessageBody">
		<xsl:choose>
			<xsl:when test="@type='action'">
				<i><xsl:value-of select="from/contact/contactDisplayName/@text" disable-output-escaping="yes"/><xsl:text> </xsl:text><xsl:value-of select="body" disable-output-escaping="yes"/></i>
			</xsl:when>
			<xsl:when test="@route='internal'">
				<span style="font-weight: bold; font-size: xx-small; color: #000; font-style: italic;">
					<xsl:value-of disable-output-escaping="yes" select="body"/>
				</span>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of disable-output-escaping="yes" select="body"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="lightenColour">
		<xsl:param name="colour"/>
		<xsl:value-of select="translate($colour,'0123456789AaBbCcDdEeFf','8899aabbccddddeeeeffff')"/>
	</xsl:template>

</xsl:stylesheet>

